package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERTaggedObject;

public class RecipientInfo extends ASN1Encodable {
   DEREncodable info;

   public RecipientInfo(KeyTransRecipientInfo info) {
      this.info = info;
   }

   public RecipientInfo(KeyAgreeRecipientInfo info) {
      RecipientInfo var10000 = this;
      super();
      DERTaggedObject var2;
      var2 = new DERTaggedObject.<init>(false, 1, info);
      var10000.info = var2;
   }

   public RecipientInfo(KEKRecipientInfo info) {
      RecipientInfo var10000 = this;
      super();
      DERTaggedObject var2;
      var2 = new DERTaggedObject.<init>(false, 2, info);
      var10000.info = var2;
   }

   public RecipientInfo(PasswordRecipientInfo info) {
      RecipientInfo var10000 = this;
      super();
      DERTaggedObject var2;
      var2 = new DERTaggedObject.<init>(false, 3, info);
      var10000.info = var2;
   }

   public RecipientInfo(OtherRecipientInfo info) {
      RecipientInfo var10000 = this;
      super();
      DERTaggedObject var2;
      var2 = new DERTaggedObject.<init>(false, 4, info);
      var10000.info = var2;
   }

   public RecipientInfo(DERObject info) {
      this.info = info;
   }

   public static RecipientInfo getInstance(Object o) {
      if (o != null && !(o instanceof RecipientInfo)) {
         if (o instanceof ASN1Sequence) {
            return new RecipientInfo((ASN1Sequence)o);
         } else if (o instanceof ASN1TaggedObject) {
            return new RecipientInfo((ASN1TaggedObject)o);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + o.getClass().getName());
         }
      } else {
         return (RecipientInfo)o;
      }
   }

   private KEKRecipientInfo getKEKInfo(ASN1TaggedObject o) {
      return o.isExplicit() ? KEKRecipientInfo.getInstance(o, true) : KEKRecipientInfo.getInstance(o, false);
   }

   public DERInteger getVersion() {
      DEREncodable var1;
      if ((var1 = this.info) instanceof ASN1TaggedObject) {
         ASN1TaggedObject var2;
         switch ((var2 = (ASN1TaggedObject)var1).getTagNo()) {
            case 1:
               return KeyAgreeRecipientInfo.getInstance(var2, false).getVersion();
            case 2:
               return this.getKEKInfo(var2).getVersion();
            case 3:
               return PasswordRecipientInfo.getInstance(var2, false).getVersion();
            case 4:
               return new DERInteger(0);
            default:
               throw new IllegalStateException("unknown tag");
         }
      } else {
         return KeyTransRecipientInfo.getInstance(var1).getVersion();
      }
   }

   public boolean isTagged() {
      return this.info instanceof ASN1TaggedObject;
   }

   public DEREncodable getInfo() {
      DEREncodable var1;
      if ((var1 = this.info) instanceof ASN1TaggedObject) {
         ASN1TaggedObject var2;
         switch ((var2 = (ASN1TaggedObject)var1).getTagNo()) {
            case 1:
               return KeyAgreeRecipientInfo.getInstance(var2, false);
            case 2:
               return this.getKEKInfo(var2);
            case 3:
               return PasswordRecipientInfo.getInstance(var2, false);
            case 4:
               return OtherRecipientInfo.getInstance(var2, false);
            default:
               throw new IllegalStateException("unknown tag");
         }
      } else {
         return KeyTransRecipientInfo.getInstance(var1);
      }
   }

   public DERObject toASN1Object() {
      return this.info.getDERObject();
   }
}
